@@ -1,7 +1,6 @@
 use syntax::ext::base::{Annotatable, ExtCtxt};
 use syntax::codemap::Span;
 use syntax::ast::{MetaItem, ItemKind, Block, VariantData, Ident, Ty};
-use syntax::attr::AttrMetaMethods;
 use syntax::ptr::P;
 use syntax::ext::build::AstBuilder;
 use syntax::parse::token::InternedString;
@@ -18,8 +17,8 @@ pub fn expand(ctx: &mut ExtCtxt,
     let item = match *annotatable {
         Annotatable::Item(ref item) => item,
         _ => {
-            ctx.span_err(span,
-                         "#[derive(ToSql)] can only be applied to tuple structs and enums");
+            ctx.span_err(span, "#[derive(ToSql)] can only be applied to structs, single field \
+                                tuple structs, and enums");
             return;
         }
     };
@@ -35,8 +34,8 @@ pub fn expand(ctx: &mut ExtCtxt,
         }
         ItemKind::Struct(VariantData::Tuple(ref fields, _), _) => {
             if fields.len() != 1 {
-                ctx.span_err(span,
-                             "#[derive(ToSql)] can only be applied to one field tuple structs");
+                ctx.span_err(span, "#[derive(ToSql)] can only be applied to structs, single field \
+                                    tuple structs, and enums");
                 return;
             }
             let inner = &fields[0].ty;
@@ -57,8 +56,8 @@ pub fn expand(ctx: &mut ExtCtxt,
              composite_to_sql_body(ctx, span, &*fields))
         }
         _ => {
-            ctx.span_err(span,
-                         "#[derive(ToSql)] can only be applied to tuple structs and enums");
+            ctx.span_err(span, "#[derive(ToSql)] can only be applied to structs, single field \
+                                tuple structs, and enums");
             return;
         }
     };
@@ -114,7 +113,7 @@ fn enum_to_sql_body(ctx: &mut ExtCtxt,
     let match_ = ctx.expr_match(span, match_arg, arms);
 
     quote_block!(ctx, {
-        let s: &'static str = $match_;
+        let s = $match_;
         try!(::std::io::Write::write_all(out, s.as_bytes()));
         ::std::result::Result::Ok(::postgres::types::IsNull::No)
     })
@@ -167,7 +166,13 @@ fn composite_to_sql_body(ctx: &mut ExtCtxt,
             match try!(r) {
                 ::postgres::types::IsNull::Yes => try!(write_be_i32(out, -1)),
                 ::postgres::types::IsNull::No => {
-                    try!(write_be_i32(out, buf.len() as i32));
+                    let len = if buf.len() > i32::max_value() as usize {
+                        return ::std::result::Result::Err(::postgres::error::Error::Conversion(
+                                "value too large to transmit".into()));
+                    } else {
+                        buf.len() as i32
+                    };
+                    try!(write_be_i32(out, len));
                     try!(::std::io::Write::write_all(out, &buf));
                 }
             }
